
== フォーマット ==
* Markdownではなく、MediaWikiのマークアップ記法で書け。
** 例えばcode blockは<pre>タグで囲むこと。
** また箇条書きには「*」を使用すること。インデントには同じ記号を重ねること（例えば箇条書きのインデントを一つ下げるなら「**」）。そのままWikipediaに掲載しても構文エラーが発生しないようにかけ。
** '''太字'''、''斜体''も、MediaWiki記法に沿って、「*」の代わりに「'」（shift+7）を正しく使用すること。
** 定義には「:」（セミコロン）を使用すること。
** 1行コードには<code>タグを使用すること。
* 文章は体言止めと、だ、である調
* 1行は長くなりすぎないように改行